@@ -6,9 +6,9 @@
          compute position and velocity from SPICE KERNEL ephemeris file.
 
   \author  M. Gastineau
-           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
+           Astronomie et Systemes Dynamiques, LTE, CNRS, Observatoire de Paris.
 
-   Copyright, 2011-2024,  CNRS
+   Copyright, 2011-2025,  CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 
   History:
@@ -1200,7 +1200,7 @@ static const struct TXTFKframe *calceph_spice_findframe_id(const struct calcephb
   @param time (in) time elapsed from JD0
   @param matrix (out) rotation matrix 3x3 from the frame idfixed to the frame
   @param idfixed (out) first non-relative frame which depends frame (=1 for J2000)
-  @param unitmatrix (out) =1, if the the rotation matrix is identity.
+  @param unitmatrix (out) =1, if the rotation matrix is identity.
      if =0, the content is unknown (may be identity or not)
 */
 /*--------------------------------------------------------------------------*/
@@ -1366,7 +1366,7 @@ int calceph_spice_findframe_matrix(const struct calcephbin_spice *eph, int id, d
    =2 : Position+Velocity+Acceleration  are computed
    =3 : Position+Velocity+Acceleration+Jerk  are computed
   @param matrix (in) rotation matrix 3x3 from the fixed frame to the frame
-  @param unitmatrix (in) =1, if the the rotation matrix is identity.
+  @param unitmatrix (in) =1, if the rotation matrix is identity.
      if =0, the content is unknown (may be identity or not)
    @param PV (out) quantities of the "target" object
    PV[0:3*(order+1)-1] are valid
