@@ -5,10 +5,10 @@
          access and interpolate SPICE Ephemeris data.
 
   \author  M. Gastineau
-           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de
+           Astronomie et Systemes Dynamiques, LTE, CNRS, Observatoire de
   Paris.
 
-   Copyright, 2011-2024, CNRS
+   Copyright, 2011-2025, CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 
   History:
@@ -337,6 +337,11 @@ struct SPKSegmentHeader_18
 /*-----------------------------------------------------------------*/
 struct SPKSegmentHeader_19
 {
+    double *boundary_times_directory;          /*!< min(N,100) : fast directory of times  if number_intervals>100
+                                   or  explicit directory if N<=100 */
+    int count_boundary_times_directory;        /*!< number of valid elements in  boundary_times_directory */
+    double *boundary_times;          /*!< n+1 directory of times */
+    double *mini_segments;      /*!< number_intervals+1 mini-segments pointer */
     int number_intervals;       /*!< number of intervals in segment */
     int boundary_choice_flag;   /*!<  boundary choice flag   */
 };
@@ -402,7 +407,7 @@ struct SPKSegmentHeader
         struct SPKSegmentHeader_2 data102;  /*!< valid if datatype= SPK_SEGTYPE102 */
         struct SPKSegmentHeader_2 data103;  /*!< valid if datatype= SPK_SEGTYPE103 */
         struct SPKSegmentHeader_20 data120; /*!< valid if datatype= SPK_SEGTYPE120 */
-    } seginfo;                  /*!< specific datq for the segment */
+    } seginfo;                  /*!< specific data for the segment */
 };
 
 /*-----------------------------------------------------------------*/
@@ -664,6 +669,10 @@ int calceph_spk_interpol_PV_segment_17(struct SPKfile *pspk, struct SPKSegmentHe
  */
 int calceph_spk_interpol_PV_segment_18(struct SPKfile *pspk, struct SPKSegmentHeader *seg,
                                        struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType * Planet);
+/*! evaluate position/velocity of a body in a segment of type 19 from a SPK file
+ */
+int calceph_spk_interpol_PV_segment_19(struct SPKfile *pspk, struct SPKSegmentHeader *seg,
+                                       struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType * Planet);
 /*! evaluate position/velocity of a body in a segment of type 20 and 120 from a
  * SPK file */
 int calceph_spk_interpol_PV_segment_20(struct SPKfile *pspk, struct SPKSegmentHeader *seg,
@@ -755,6 +764,11 @@ enum SPKBinaryFileFormat calceph_bff_detect(struct SPKHeader *header);
 void calceph_bff_convert_array_double(double *x, int n, enum SPKBinaryFileFormat reqconvert);
 void calceph_bff_reorder_array_int(int *x, int n, enum SPKBinaryFileFormat reqconvert);
 
+int calceph_spk_readsegment_header_18(FILE * file, const char *filename, struct SPKSegmentHeader *seg);
+int calceph_spk_readsegment_header_19(FILE * file, const char *filename, struct SPKSegmentHeader *seg);
+
+int calceph_spk_allocate_directory(int count_directory, double **directory);
+
 /*-----------------------------------------------------------------*/
 /*! internal functions to read text kernel files */
 /*-----------------------------------------------------------------*/
