@@ -6,10 +6,10 @@
          compute position and velocity from SPICE KERNEL ephemeris file.
 
   \author  M. Gastineau
-           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de
+           Astronomie et Systemes Dynamiques, LTE, CNRS, Observatoire de
   Paris.
 
-   Copyright, 2011-2024, CNRS
+   Copyright, 2011-2025, CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 
   History:
@@ -111,7 +111,6 @@ static int calceph_spk_readsegment_header(FILE * file, const char *filename, str
 static void calceph_spk_convertheader(struct SPKHeader *header, enum SPKBinaryFileFormat reqconvert);
 
 static int calceph_bff_convert_int(int x, enum SPKBinaryFileFormat reqconvert);
-static int calceph_spk_allocate_directory(int count_directory, double **directory);
 
 /*--------------------------------------------------------------------------*/
 /*!
@@ -127,7 +126,7 @@ static int calceph_spk_allocate_directory(int count_directory, double **director
   @param res (out) descriptor of the ephemeris.
 */
 /*--------------------------------------------------------------------------*/
-int calceph_spk_open(FILE * file, const char *filename, struct SPICEkernel *res)
+int calceph_spk_open(FILE *file, const char *filename, struct SPICEkernel *res)
 {
     buffer_error_t buffer_error;
     struct SPKHeader header;
@@ -236,6 +235,12 @@ void calceph_spk_close(struct SPKfile *eph)
                 case SPK_SEGTYPE18:
                     free(pheader->seginfo.data18.directory);
                     break;
+                case SPK_SEGTYPE19:
+                    if (pheader->seginfo.data19.boundary_times_directory)
+                        free(pheader->seginfo.data19.boundary_times_directory);
+                    free(pheader->seginfo.data19.boundary_times);
+                    free(pheader->seginfo.data19.mini_segments);
+                    break;
                 case SPK_SEGTYPE21:
                     free(pheader->seginfo.data21.directory);
                     break;
@@ -366,7 +371,7 @@ static void calceph_spk_convertheader(struct SPKHeader *header, enum SPKBinaryFi
 
 */
 /*--------------------------------------------------------------------------*/
-static int calceph_spk_allocate_directory(int count_directory, double **directory)
+int calceph_spk_allocate_directory(int count_directory, double **directory)
 {
     *directory = (double *) malloc(count_directory * sizeof(double));
     if (*directory == NULL)
@@ -443,7 +448,7 @@ int calceph_spk_ftp(const unsigned char ftpbuf[FTP_LEN])
    @param reqconvert (in) binary file format
 */
 /*--------------------------------------------------------------------------*/
-static int calceph_spk_readlistsegment(FILE * file, const char *filename, struct SPKSegmentList **list,
+static int calceph_spk_readlistsegment(FILE *file, const char *filename, struct SPKSegmentList **list,
                                        int fwd, int PARAMETER_UNUSED(bwd), enum SPKBinaryFileFormat reqconvert)
 {
 #if HAVE_PRAGMA_UNUSED
@@ -605,7 +610,7 @@ static int calceph_spk_readlistsegment(FILE * file, const char *filename, struct
    @param record (out) array to store the words
 */
 /*--------------------------------------------------------------------------*/
-int calceph_spk_readword(FILE * file, const char *filename, int rec_begin, int rec_end, double *record)
+int calceph_spk_readword(FILE *file, const char *filename, int rec_begin, int rec_end, double *record)
 {
     buffer_error_t buffer_error;
     size_t n = (size_t) (rec_end - rec_begin + 1);
@@ -784,7 +789,7 @@ void calceph_spk_debugsegment(struct SPKSegmentHeader *seg)
    @param seg (inout) segment
 */
 /*--------------------------------------------------------------------------*/
-static int calceph_spk_readsegment_header(FILE * file, const char *filename, struct SPKSegmentHeader *seg)
+static int calceph_spk_readsegment_header(FILE *file, const char *filename, struct SPKSegmentHeader *seg)
 {
     double drecord[12];
 
@@ -911,9 +916,11 @@ static int calceph_spk_readsegment_header(FILE * file, const char *filename, str
                 res = calceph_spk_allocate_directory(seg->seginfo.data13.count_directory,
                                                      &seg->seginfo.data13.directory);
                 if (res == 1)
+                {
                     res = calceph_spk_readword(file, filename, seg->rec_end - 2 - ndirectory + 1, seg->rec_end - 2,
                                                seg->seginfo.data13.directory);
-                calceph_bff_convert_array_double(seg->seginfo.data13.directory, ndirectory, seg->bff);
+                    calceph_bff_convert_array_double(seg->seginfo.data13.directory, ndirectory, seg->bff);
+                }
             }
             break;
 
@@ -942,51 +949,11 @@ static int calceph_spk_readsegment_header(FILE * file, const char *filename, str
             break;
 
         case SPK_SEGTYPE18:
-            res = calceph_spk_readword(file, filename, seg->rec_end - 2, seg->rec_end, drecord);
-            if (res == 1)
-            {
-                int nrecord, ndirectory;
-
-                calceph_bff_convert_array_double(drecord, 3, seg->bff);
-
-                seg->seginfo.data18.subtype = (int) drecord[0];
-                seg->seginfo.data18.window_size = (int) drecord[1];
-                nrecord = (int) drecord[2];
-                ndirectory = nrecord;
-                seg->seginfo.data18.count_record = nrecord;
-                switch (seg->seginfo.data18.subtype)
-                {
-                    case 0:
-                        seg->seginfo.data18.degree = 2 * seg->seginfo.data18.window_size - 1;
-                        break;
-                    case 1:
-                        seg->seginfo.data18.degree = seg->seginfo.data18.window_size - 1;
-                        break;
-                    default:
-                        fatalerror("Unknown subtype for ESOC/DDID Hermite/Lagrange Interpolation");
-                        break;
-                }
-                if (nrecord >= 100)
-                    ndirectory = (nrecord / 100);
-                seg->seginfo.data18.count_directory = ndirectory;
-                res = calceph_spk_allocate_directory(seg->seginfo.data18.count_directory,
-                                                     &seg->seginfo.data18.directory);
-                if (res == 1)
-                    res = calceph_spk_readword(file, filename, seg->rec_end - 3 - ndirectory + 1, seg->rec_end - 3,
-                                               seg->seginfo.data18.directory);
-                calceph_bff_convert_array_double(seg->seginfo.data18.directory, ndirectory, seg->bff);
-            }
+            res = calceph_spk_readsegment_header_18(file, filename, seg);
             break;
 
         case SPK_SEGTYPE19:
-            res = calceph_spk_readword(file, filename, seg->rec_end - 1, seg->rec_end, drecord);
-            if (res == 1)
-            {
-                calceph_bff_convert_array_double(drecord, 2, seg->bff);
-
-                seg->seginfo.data19.boundary_choice_flag = (int) drecord[0];
-                seg->seginfo.data19.number_intervals = (int) drecord[1];
-            }
+            res = calceph_spk_readsegment_header_19(file, filename, seg);
             break;
 
         case SPK_SEGTYPE21:
@@ -1009,9 +976,11 @@ static int calceph_spk_readsegment_header(FILE * file, const char *filename, str
                 res = calceph_spk_allocate_directory(seg->seginfo.data21.count_directory,
                                                      &seg->seginfo.data21.directory);
                 if (res == 1)
+                {
                     res = calceph_spk_readword(file, filename, seg->rec_end - 2 - ndirectory + 1, seg->rec_end - 2,
                                                seg->seginfo.data21.directory);
-                calceph_bff_convert_array_double(seg->seginfo.data21.directory, ndirectory, seg->bff);
+                    calceph_bff_convert_array_double(seg->seginfo.data21.directory, ndirectory, seg->bff);
+                }
             }
             break;
 
@@ -1047,7 +1016,7 @@ static int calceph_spk_readsegment_header(FILE * file, const char *filename, str
 */
 /*--------------------------------------------------------------------------*/
 int calceph_spk_interpol_PV_segment(struct SPKfile *pspk, struct SPKSegmentHeader *seg,
-                                    struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType * Planet)
+                                    struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType *Planet)
 {
     int res = 0;
 
@@ -1091,6 +1060,10 @@ int calceph_spk_interpol_PV_segment(struct SPKfile *pspk, struct SPKSegmentHeade
             res = calceph_spk_interpol_PV_segment_18(pspk, seg, cache, TimeJD0, Timediff, Planet);
             break;
 
+        case SPK_SEGTYPE19:
+            res = calceph_spk_interpol_PV_segment_19(pspk, seg, cache, TimeJD0, Timediff, Planet);
+            break;
+
         case SPK_SEGTYPE120:
         case SPK_SEGTYPE20:
             res = calceph_spk_interpol_PV_segment_20(pspk, seg, cache, TimeJD0, Timediff, Planet);
